#!/bin/sh
# This file is in the public domain

case $1 in
# get pre-requisites
prereqs)
	echo ""
        exit 0
        ;;
esac

. /usr/share/initramfs-tools/hook-functions

####

my_packages='
bash
bc
bsdmainutils
bzip2
coreutils
cpio
diffutils
dump
dosfstools
e2fsprogs
extlinux
findutils
grep
gzip
iputils-ping
kmod
login
mawk
mount
net-tools
netcat-traditional
ntfs-3g
nvi
openssh-client
pciutils
procps
rsync
strace
sysvinit-core
tar
util-linux
xz-utils
'

$CRYPT && my_packages="$my_packages cryptsetup"
$LVM &&   my_packages="$my_packages dmsetup lvm2"

my_modules='fat vfat msdos ntfs nls_cp437 nls_utf8 powernow-k7'

# needed to mount other filesystem types:
for p in $my_modules; do 
    manual_add_modules $p;
done

for p in $my_packages; do 
    dpkg -L $p | egrep '^/(usr/)?s?bin/' | while read f; do
        [ -f $f ] && [ -x $f ] || continue
	copy_exec $(readlink -f $f) /rescue/$(basename $f)
    done
done

awk -F: '/^(root|bin|daemon|disk|kmem|sys|tty):/ { print $1":"$2":"$3":" }' \
    /etc/group > ${DESTDIR}/etc/group

awk -F: '/^(root|bin|daemon|sys):/' /etc/passwd > ${DESTDIR}/etc/passwd

find	/etc/nsswitch.conf \
	/lib/*-linux-gnu/libnsl*.so \
	/lib/*-linux-gnu/libnss_[cdf]*.so \
	/lib/terminfo \
	/usr/lib/EXTLINUX \
    -type f | cpio -pdm ${DESTDIR}

echo 'PATH=/rescue:${PATH}; export PATH' >${DESTDIR}/etc/profile

ln -s /lib/systemd/systemd-udevd ${DESTDIR}/sbin/udevd
ln -s /rescue/bash ${DESTDIR}/bin

cat >${DESTDIR}/etc/inittab <<'_EOITAB'
id:2:initdefault:
1:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty1
2:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty2
3:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty3
4:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty4
5:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty5
6:23:respawn:/rescue/agetty -l /rescue/bash -o -l -a root --noclear 38400 tty6
_EOITAB

# ln -s /proc/mounts ${DESTDIR}/etc/mtab

cat >${DESTDIR}/init <<'_EOINIT'
#!/bin/sh

set -x

mkdir -p /dev /proc /root /run /sys /tmp /var/lock /var/run /var/tmp

mount -t devtmpfs -o mode=0755 none /dev
mount -t sysfs -o nodev,noexec,nosuid none /sys
mount -t proc -o nodev,noexec,nosuid none /proc

mkdir /dev/pts
mount -t devpts -o noexec,nosuid,gid=5,mode=0620 none /dev/pts
mount -t tmpfs -o nosuid,mode=0755 tmpfs /run

udevd --daemon
udevadm trigger --action=add
udevadm settle || true

exec /rescue/init </dev/console >/dev/console 2>&1
_EOINIT


